# Export
export(SK)
export(plot.SK)
export(print.SK)
export(summary.SK)
export(boxplot.SK)
export(xtable.SK)
export(xtable)

# Import all packages listed as Imports or Depends
importFrom(emmeans, emmeans)
importFrom(xtable, xtable)
import(
 utils,
 stats,
 graphics
)

# S3 methods
S3method(SK,default)
S3method(SK, formula)
S3method(SK, lm)
S3method(SK, aovlist)
S3method(SK, lmerMod)
S3method(SK, nest.lm)
S3method(SK, nest.aovlist)
S3method(SK, nest.lmerMod)
S3method(summary, SK)
S3method(print, SK)
S3method(xtable,SK)
S3method(print,xtable.SK)
S3method(plot, SK)
S3method(boxplot, SK)
